bayespy.inference.vmp.nodes.deterministic.Deterministic
=======================================================

.. currentmodule:: bayespy.inference.vmp.nodes.deterministic

.. autoclass:: Deterministic

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: generated/
   
      ~Deterministic.__init__
      ~Deterministic.add_plate_axis
      ~Deterministic.broadcasting_multiplier
      ~Deterministic.delete
      ~Deterministic.get_mask
      ~Deterministic.get_moments
      ~Deterministic.get_shape
      ~Deterministic.has_plotter
      ~Deterministic.lower_bound_contribution
      ~Deterministic.move_plates
      ~Deterministic.plot
      ~Deterministic.set_plotter
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
      :toctree: generated/
   
      ~Deterministic.plates
      ~Deterministic.plates_multiplier
   
   